from setuptools import setup, find_packages

setup(
    name='config_utilities',
    version='0.3.2',
    packages=find_packages(),
    install_requires=[],
    description='Utilities for configuration management and logging setup.',
    author='Steffen S. Rasmussen',
    author_email='steffen@audkus.dk',
    url='https://github.com/audkus/config_utilities.git',
    license='MIT',
)
